# CLI
## Mock Test

### Progress
All Done !!

# SDK

## Mock Test

### Progress
All Done !!

## Integration Test 
### Progress
- test_dataset.py -> 완료
- test_model.py -> 완료
- test_finetuning.py
- test_finetuning.py -m cancel / finetuning 요청 이후 시작하고 나면 취소
- test_finetuning.py -m complete / finetuning 요청 후 완료될 때까지 모니터링, 버전과 모델이 생성되는지 확인. TEST_FINETUNING_IS_AUTO_MODEL_CREATION 값이 false 이면 version 만 생성이 되기 때문에, 모델이 생성되는 과정을 test 하면 안됨 -> 추가 처리 완료. 테스트 필요.
- test_prompt.py -> 완료, 다중 tag 검색 기능이 동작하지 않음. API 수정 필요
- test_authorization.py -> 완료
- test_agent_app.py
- test_agent_graph.py
- test_apikey.py -> created_at 이 날짜까지임.
- test_knowledge.py